package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(<@`````````0```````
M`+%@``````!``#@`"0!``!<`%@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M7`````````)<`````````EP`````````&``````````8``````````$````!
M````!0```````````````````````````````````````*'\````````H?P`
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!+@````````%$````````!```````@````8```````"KV````````+O8````
M````N]@````````!X`````````'@``````````@````$````!`````````(X
M`````````C@````````".``````````D`````````"0`````````!&1TY5``
M```$````````FZ````````";H````````)N@`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O(````````N\@`````
M``"[R`````````0X````````!#@``````````0````0````4`````T=.50"-
M.;#V3+08`-@DP+^V9@N="C"_1R]L:6(O;&0M;75S;"US,SDP>"YS;RXQ````
M```````1````10````0````(@`1`!0`0$""$`(:`!!``*`D$``D"`*&""`($
MND$8@(@`````````10```$D```!-````3@```%4```!6````5P````````!9
M````6@````````!;````7````%X``````````"U'WLX?W\5N?)I_:@[OT^NV
MF\4N#O&-N`[D_R!\U&35'%AQV6^+`;*;PT^8+#_EPH?7^D)@;*'Z?)+CN@'&
M1^/2/,-59LRO9]-P!XCLU45#[=MB,\PEC!6;G*E_"@*GX%">&FM)^^"C````
M```````````````````````````````````````#```(````````&"@`````
M`````````F@2`````````````````````````````8T2````````````````
M`````````````$L2`````````````````````````````G<2````````````
M`````````````````6$2`````````````````````````````#T2````````
M`````````````````````1(2`````````````````````````````=`2````
M`````````````````````````*,2`````````````````````````````*PB
M`````````````````````````````2H2````````````````````````````
M`;42`````````````````````````````E82````````````````````````
M`````7(2`````````````````````````````/42````````````````````
M`````````F\2`````````````````````````````KDA````````````````
M`````````````#<2`````````````````````````````K@1````````````
M`````````````````:@1`````````````````````````````1D2````````
M`````````````````````C\2`````````````````````````````%L2````
M`````````````````````````>\2`````````````````````````````KH1
M`````````````````````````````)02````````````````````````````
M`A82`````````````````````````````!\@````````````````````````
M`````3\2`````````````````````````````-8@````````````````````
M`````````K<A`````````````````````````````&,2````````````````
M`````````````/`2`````````````````````````````%,2````````````
M`````````````````$02`````````````````````````````!`2````````
M`````````````````````@T2`````````````````````````````H`2````
M`````````````````````````8$2`````````````````````````````'(@
M`````````````````````````````H<2````````````````````````````
M`B\2`````````````````````````````=P2````````````````````````
M``````$2`````````````````````````````^,2````````````````````
M`````````B$2`````````````````````````````IT2````````````````
M``````````````D1`````````````````````````````?T2````````````
M`````````````````&02`````````````````````````````ET2````````
M`````````````````````!@2`````````````````````````````/L2````
M`````````````````````````-$2`````````````````````````````4X6
M`````````````````````````````HX2````````````````````````````
M`J42`````````````````````````````(X2````````````````````````
M`````)P2`````````````````````````````&D2````````````````````
M`````````3$2`````````````````````````````DH2````````````````
M`````````````0P2`````````````````````````````+L@````````````
M`````````````````<82`````````````````````````````),2````````
M`````````````````````<L2`````````````````````````````VL2```*
M````````-^`````````&/````W@2```*````````0(@`````````T````K(2
M```*````````'T@````````"@````:(2```+````````6P```````````@``
M`N\2```*````````*F@`````````!@```^\2```(````````&"@`````````
M`@```R02```*````````*G`````````";````SD2```*````````/B``````
M```"9@```X00```4````````P(```````````````PH2```*````````-!``
M````````@````S$2```*````````-)``````````=````T\2```*````````
M*0@`````````.````V`2```*````````6&@````````!F````Y`2```*````
M````-R``````````P````[\0```4````````P-@``````````````\02```*
M````````+.``````````-@```U<2```*````````(?@`````````/````Q@2
M```*````````+1@````````!8@```P`1```3````````P'@`````````"```
M`[@0```4````````P(```````````````XD2```*````````(<@`````````
M`````^P2```*````````5_@`````````;````]$2```*````````-O``````
M````+````Z(2```*````````*4`````````!)````_42```*````````6@``
M````````_````N(2```*````````+H`````````%C`!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR`&QS=&%T
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'9F
M<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES
M=&5R7V9R86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`')E860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!M96UC<'D`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?
M9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A9&1I<@!S;G!R:6YT9@!S=')T
M;VL`<W1R9'5P`'!T:')E861?871F;W)K`'-P<FEN=&8`7U]L:6)C7W-T87)T
M7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US,SDP>"YS
M;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C`&UY7W!A<E]P;`!P
M87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P87)?9&EE
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C`'-H85]U
M<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?8G-S7W-T87)T`'!A
M<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O8P!?961A=&$`
M7V5N9`!P87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M<VAA7VEN:70`<VAA7V9I;F%L`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#
M3U)%`````````````+O(``````````P````````C$````````+O0````````
M``P````````BJ````````+^@``````````P````````8*````````+_0````
M``````P````````?2````````+_@``````````P```````!;`````````,``
M``````````P```````#``````````,`8``````````P```````!>#```````
M`,`@``````````P```````!;:````````,`P``````````P```````!<"```
M`````,`X``````````P```````!<#````````,!```````````P```````!>
M`````````,!(``````````P```````!;;@```````,!0``````````P`````
M``!>"````````,!@``````````P```````!=\````````,!H``````````P`
M``````!=]@```````,!X``````````P```````!>$@```````+^(````!@``
M``H``````````````````+^0````"P````H``````````````````+^8````
M%0````H``````````````````+^H````&@````H``````````````````+^P
M````'0````H``````````````````+^X````'P````H`````````````````
M`+_`````*0````H``````````````````+_(````*P````H`````````````
M`````+_8````+`````H``````````````````+_H````,0````H`````````
M`````````+_P````.````#@``````````````````+_X````00````H`````
M`````````````+W0`````@````L``````````````````+W8`````P````L`
M`````````````````+W@````!`````L``````````````````+WH````!0``
M``L``````````````````+WP````!P````L``````````````````+WX````
M"`````L``````````````````+X`````"0````L``````````````````+X(
M````"@````L``````````````````+X0````"P````L`````````````````
M`+X8````#`````L``````````````````+X@````#0````L`````````````
M`````+XH````#@````L``````````````````+XP````#P````L`````````
M`````````+XX````$`````L``````````````````+Y`````$0````L`````
M`````````````+Y(````$P````L``````````````````+Y0````%@````L`
M`````````````````+Y8````%P````L``````````````````+Y@````&```
M``L``````````````````+YH````&0````L``````````````````+YP````
M&P````L``````````````````+YX````'`````L``````````````````+Z`
M````'0````L``````````````````+Z(````'@````L`````````````````
M`+Z0````(0````L``````````````````+Z8````(@````L`````````````
M`````+Z@````(P````L``````````````````+ZH````)`````L`````````
M`````````+ZP````)0````L``````````````````+ZX````)@````L`````
M`````````````+[`````)P````L``````````````````+[(````*`````L`
M`````````````````+[0````*@````L``````````````````+[8````+0``
M``L``````````````````+[@````+@````L``````````````````+[H````
M+P````L``````````````````+[P````,`````L``````````````````+[X
M````,@````L``````````````````+\`````,P````L`````````````````
M`+\(````-`````L``````````````````+\0````-0````L`````````````
M`````+\8````-@````L``````````````````+\@````-P````L`````````
M`````````+\H````.0````L``````````````````+\P````.@````L`````
M`````````````+\X````.P````L``````````````````+]`````/`````L`
M`````````````````+](````/0````L``````````````````+]0````/@``
M``L``````````````````+]8````/P````L``````````````````+]@````
M0`````L``````````````````+]H````00````L``````````````````+]P
M````0@````L``````````````````+]X````0P````L`````````````````
M`+^`````1`````L``````````.OO\'``)+D$``^G^_]@XP#P```DZ^_Q$``$
M!_[C$/`X`"3`$```4K?2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!2MN,0$```
M!`?Q#1#C$!`,`!3`]/___^4`````P!```%*JXQ`0```$!_$-$.,0$`P`%,#T
M____U0```!C`$```4I[C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!2
MDN,0$```!`?Q#1#C$!`,`!3`]/___[4```!(P!```%*&XQ`0```$!_$-$.,0
M$`P`%,#T____I0```&#`$```4GKC$!````0'\0T0XQ`0#``4P/3___^5````
M>,`0``!2;N,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```%)BXQ`0```$
M!_$-$.,0$`P`%,#T____=0```*C`$```4E;C$!````0'\0T0XQ`0#``4P/3_
M__]E````P,`0``!22N,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```%(^
MXQ`0```$!_$-$.,0$`P`%,#T____10```/#`$```4C+C$!````0'\0T0XQ`0
M#``4P/3___\U```!",`0``!2)N,0$```!`?Q#1#C$!`,`!3`]/___R4```$@
MP!```%(:XQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```4@[C$!````0'
M\0T0XQ`0#``4P/3___\%```!4,`0``!2`N,0$```!`?Q#1#C$!`,`!3`]/__
M_O4```%HP!```%'VXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```4>KC
M$!````0'\0T0XQ`0#``4P/3___[5```!F,`0``!1WN,0$```!`?Q#1#C$!`,
M`!3`]/___L4```&PP!```%'2XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`
M$```4<;C$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!1NN,0$```!`?Q
M#1#C$!`,`!3`]/___I4```'XP!```%&NXQ`0```$!_$-$.,0$`P`%,#T___^
MA0```A#`$```4:+C$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!1EN,0
M$```!`?Q#1#C$!`,`!3`]/___F4```)`P!```%&*XQ`0```$!_$-$.,0$`P`
M%,#T___^50```EC`$```47[C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0
M``!1<N,0$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```%%FXQ`0```$!_$-
M$.,0$`P`%,#T___^)0```J#`$```45KC$!````0'\0T0XQ`0#``4P/3___X5
M```"N,`0``!13N,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```%%"XQ`0
M```$!_$-$.,0$`P`%,#T___]]0```NC`$```43;C$!````0'\0T0XQ`0#``4
MP/3___WE```#`,`0``!1*N,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!``
M`%$>XQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`$```41+C$!````0'\0T0
MXQ`0#``4P/3___VU```#2,`0``!1!N,0$```!`?Q#1#C$!`,`!3`]/___:4`
M``-@P!```%#ZXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```4.[C$!``
M``0'\0T0XQ`0#``4P/3___V%```#D,`0``!0XN,0$```!`?Q#1#C$!`,`!3`
M]/___74```.HP!```%#6XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```
M4,KC$!````0'\0T0XQ`0#``4P/3___U5```#V,`0``!0ON,0$```!`?Q#1#C
M$!`,`!3`]/___44```/PP!```%"RXQ`0```$!_$-$.,0$`P`%,#T___]-0``
M!`C`$```4*;C$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!0FN,0$```
M!`?Q#1#C$!`,`!3`]/___14```0XP!```%".XQ`0```$!_$-$.,0$`P`%,#T
M___]!0``!%#`$```4(+C$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!0
M=N,0$```!`?Q#1#C$!`,`!3`]/___.4```2`P!```%!JXQ`0```$!_$-$.,0
M$`P`%,#T___\U0``!)C`$```4%[C$!````0'\0T0XQ`0#``4P/3___S%```$
ML,`0``!04N,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```%!&XQ`0```$
M!_$-$.,0$`P`%,#T___\I0``!.#`$```4#KC$!````0'\0T0XQ`0#``4P/3_
M__R5```$^,`0``!0+N,0$```!`?Q#1#C$!`,`!3`]/___(4```40`````.MO
M\#``)./P_SC_<>,P\*@`).-`\*``)%`@\+1!0/"@03#PJ$$@\+2R3P"PZ[L`
M(``-LD\`L=('\,"P*,#E___]X,1(``!0)\0H``!/_+D$`#3`Y?___Q7$&```
M3_R5`!``IX0`ML`P``!0(>-0,```!%B@\+3LF@`$`-BY%`#IXV6P```$ZRX`
M`P`-E@-DBJ>J``/`Y?___U3C$/"H``3`,```'P#C`!````3C,"`(`"3C`"``
M`"2Y!`!2Q"L``%!>P$```![QXT!0&``DQ"@``%`QXR!0$``D6)#PM.R<`,4!
M?NSI``,`V.P)__\`V$$P$`BG*``$IP$``:=T`(*(```!N10`0NP2``$`V.OD
M``,`#;D4`&'C0#````3C3E```"3K%@`#``WC8#`(``3C85```"2G*@`"ISL`
M$*<&_^/L:0`#`-BY%`"6N10`2NNI``,`#4$J4`"G:0``Y4@@````P#````/R
MQ"@``%`/P.7___SF["@`5`!^Q"@``%`&06#PO,#E___]^[D$`#:Y!`"2P"``
M`!UOP.4```$W["@`1P!\Q"@``$_QP.7___[XP.7___ZUU0?PP+`HIW0`6;D$
M`"GK;_#X``0'_L#E___^%\0K``!/VNPH`$X`?,#E___\7L`P``!/8>,@,```
M!.-"L```!)(`24:G]/\XXS`P```$XS!0(``DIR@`!4$P$!#L+O]V8':G]/^4
MQ"@``$^UP.7___U,I_3_J<!0``!/J>,@4````J>$``?`Y0``#X&G]/^QN00`
M-L`@```<Z\#E````V\0K``!/E.PH_Z0`?*?T_^VG:``$I_3_;L#E___\5J<I
M``'`Y?___?&Y!``OP#`````2XS`P```8I_O_8*<)``#C`/```"3`]`````D'
M!P<'``"9Z`<'!P?K;_`P`"1!0"`(X_#_6/]QQ&@``$[LY4CPH```Q%@``$[&
MXS`@!``4Q"@``$[8P.7___W?ZV_PV``$!_X'!P<'P!```$\DP"```$\A[!(`
M"H!DQ!@``$Z[[!@`!`!\!_$'_@<'!P<'!\`0``!/$,`@``!/#;D)`!+K`0`#
M``KK,0`_``RY"``PZS,``0`*[#@`#0!\Q!@``$Z6[!@`!P!\P"```$[T!_$'
M_@<'!P<'!^N_\%@`),"P``!.Z>/P_V#_<94`L`"G=``CP!```$YGXQ`0```"
MIX0`",0H``!.E\#E___[1L#E____K<`@``!.9N,0(````J>$``C`(```/,+`
MY?___!62`;``Z[_P^``$!_X'!P<'P!```$YTXQ`0```"IX0`%^OO\'``),`P
M``!.L>/P_V#_<<`@```\H\#E___]QNOO\1``!,#T____CL#T____B^MO\#``
M),08``!.*>/P_V#_<>-P$````J>$`%.Y!`""N00`8^,`(```E+D$`)*5`"``
MIX0`2NP(``P]?D&0D`'C`)```)25`)``IW3_]AN8XZ!P```"IX0`'[D4`)FY
M!`"WN00`2;D$`#BY!``JP.7___OS["8`"0!^02F@`)4](`"GA``/0;"P"..@
ML````J=T_^FY!``JZV_PT``$!_Y!J:`!N>EP.[D$`"KK0P`#``I00&``ZV_P
MT``$!_ZGJ0``I_3_Z:>8``"G]/_#!P?KK_!0`"3C\/[(_W&R3P"PN00`HNN[
M`"``#4$P\*"R3P"QT@?Q,+`HP.7___N.["8`(0!^&!*G.$``6"#PN,`K``#P
M`.PC``B`=J4/H`#L(``38':Y!``JISD``L#E___\=!`2IQK__X@0`!^G]``$
MIQ@``-4'\3"P*+D4`"&G=``&ZZ_QB``$!_[`Y?__^MWKC_!``"3C\/[(_W&R
M3P"`ZX@`(``-LD\`@=('\3"`*.PH``D`?+D$`+*5`"``IW0`"]4'\3"`**=T
M`)'KC_%X``0'_L#E___[R+D$`)+L*/_R`'RY!``IP.7___J.["@`80!\0:`@
M$Y4N(!.G=``&E0"@`:>$__"5+B`3IX0`7J<(``"Y!``ZN00`&Z=)``"R7@!#
MIQ3__KD)`$JG*0``LEX`(:<4__ZY"0`K&B2G*@`"N10`(L#E___Z+[D$`%K`
M,```&MBY!`"BN00`2\#E___[L[D$`"I!,/"@P.7___O,["@`#?]^6`#PN*=8
M0`#`"P``\`#L!0`K@':Y!``JP.7___L*N00`*L#E___\M;D$`"G`Y?__^C#L
M)O^E`'RY!``IP.7___PXN00`*\#E___Z$Z?T_W^5+J`!IW3_HI4`H`*GA/^(
MI_3_G+D$`"K`Y?___UBG]/_8P.7___HMZV_P,``DX_#_2/]QLD\`8.MF`"``
M#;)/`&&5/3``T@?PL&`H0:`P`;GB<*.G"```N00`&J>)``"Y!`"RLEX`@:<4
M__Y!,/"LN0D`BL#E___^>NPH`)<`?*<(``"GV0``N00`XK)>`-ZG%/_^N0D`
MTNR-`';`9>,`\*P`%,38``!,CNMP``,`#>,@L```E+D$`$N5`+``IW0`#:?T
M`.9!0$`!XR!```"4E0!``*>$``7L)O_W/7ZY"0!+N10`E$$HD`*Y!`"'XX#0
M```(P.7___ETXR"````D["@`.0!\XS#0```$XU"P``"0X^<P```$0E#@`$%P
ML`$8!>Q6`!``?*?T`#SC$'```)!"$+`!07!P`1@![!@`,@!\0@#PH+D$`+Z5
M/?"@0>#@`:=T_^V2/;``I]D``.--H```D$)-L`&GVP`![$;_^0!\U0?PL&`H
MIW0`E>MO\.@`!`?^IYD``..)H```D$*)(`"GFP`![(;_^0!\I_3_Z[D$`+ZG
M]/_9Q-@``$P,XW#0```$XQ!P```"IX0`;KD$`$>GF```&"FGF@`!04!`".,P
M0````J=T__BG*@`#N10``NL@``,`#<`P``!,=.,0,```$J=T`#;`4```3&SE
M3%````'`Y?__^.SC(/"@`"3L*/^Q`'RY%`#IN00`-^M^``,`#;D$`$?`Y?__
M^$KC(/"@``3C(-```"10D/"LXU#PH``$IYH``;D4`)GK.0`#``U!$U``Y4@0
M````I_3_*KD$`#*Y!``GP.7___G*XR#PH``DXR#0```D["C_?`!\N10`2>MT
M``,`#:?T_]BGF0``I_3_*J<I`!"GF```I_3_I<#E___X[>MO\#``),`0``!+
MK>/P_UC_<>.P$```!,!0```Y<,1(``!+C<`P```9.;)/`*#KJ@`@``VR3P"A
MXRN@```$P&```!J,P.7___D8N00`5N5(\*```,!````*GN,KH```!,`P```9
M*<#E___X5^MO\-@`!`?^!P<'![)/`"#`$```2W+K,@`@``WC0!````2R3P`Q
MP%```#DSXR0P```$Q$@``$M-P#```!CYP/3___CEZV_P,``DX_#P`/]QXP#_
M^``@X_#P`/]QXP#_^``@X_#_4/]QXP#PJ``@XQ#PJ`)QLD\`D.N9`"``#;)/
M`)%!L/"FT@<0`)`HP.7___>NP&```!CEN00`4L!````8XKD$`"NG.1`!P.7_
M__>/["@`5?]^N00``N.`\*<!<;D$`"NY!``X[``0`"!QITD0`,#E___WN[D$
M`&+L)``_`'ZG*@`!N10`(L#E___W[[D$`*+L*``S`'RY%`"V["@`!Z!EN>BP
M,KEA0(/LJ``A(&6Y!``XN00`2[D$`"KLL!`!(''`Y?__]W)!6Z``D@!0`./@
M\*@"<=4'X`"0**=T`!*Y!``JZV_PX`($!_ZYZ+!(N6%`I*?T_]ZGJ0``I_3_
MZL#E___X`P<'!P?`]/___VP'!^MO\#``)./P\`#_<>,`__@`(./P_KC_<>,`
M\4``(.,0\4`!<;D$`+*Y!`"3LD\`<$$P\*SK=P`@``W`(```&&"R3P!QT@<0
M`'`HP.7___Q+ISD`+[D$`**Y!``KP.7___FL["@`&0!\P"```!A.N00`.\#E
M___]E[D$`"OC@/%``7'5!X``<"BG=`#OZV_Q>`$$!_ZY!``IP.7___BNP#``
M`!@ZP.7___B(N00`4NPH_]T`?$&0\4!!@/"PE0!0`*>$`)CLJ``/`'RG"```
MN00`-;D$`"JR70`RIQ3__J>$`'BG"```ITD``+D$`&6R7@!&IQ3__KGI4"3C
M$$___W'L40`WH&6YZ5`!IP$``:>$``Z5+Q``IW0`()(`$`#C$!___W'L40`9
M@&3KX``!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?__]2XQ`?_O]QI^?_
M[Z<(``"G*0``N00`-;)>`".G%/_^N0D`):<(``"G20``N00`:Z?I#_^R7@!&
MIQ3__KD)`$M!!"`![`[_;2!EX[#PH``DN00`*<!@```7N\!````8,J<Y$`#`
MY?__]E.G6!``IRH``>PE`"C`=Z?T``&5`*`!IW0`&L`P```7HJ<I``#`Y?__
M]^ZY!`!2["C_0P!\E0!0`*=T_VSLJ``'`'R5+J``IX3_YJ<I``'`4```%WNG
M]/^SN00`.+D$`"G`Y?__^%#L)O_:`'Y8$/#(I3^``,`;``#P`.P3_]!@=KD$
M`"FG.0`!P.7___A<[";_Q@!^N00`.<`@```77,#E___\I[D$`"G`Y?__]\RG
M]/\-P.7___;'!P<'!^N_\%@`)*<Y`"^Y!`"RX_#_8/]QP.7___;801`@`;D"
M`"*Y!``KN>)P(>N_\/@`!,#T___WJ@<'ZZ_P4``DX_#P`/]QXP#_^``@X_#_
M6/]QXP#PH``@LD\`L.,0\*`!<>N[`"``#;)/`+'2!Q``L"CL*`!K`'RY!``R
ME0`@`*>$`&2G"```ITD``+)>`$*G%/_^IPD0`+D)`$.G2P`![$``=R!E0:#P
MH+D$`"K`Y?__]6RG"```ISD``+D$`%JR7@`UIQ3__N,0/___<>P:`!_`9;GI
MH.&G$0`!IW0`1^M.``$`#)4O$`"G=``1D@`0`.LO'___5:=T``KK`!___U+C
M$!_^_W&G1__ON00`*J<Y`"_`Y?__]EGL*``7`'SL*@`S(&6Y!``JP.7___<N
MXS#PH`%QU0<P`+`HIW0`+>NO\/@!!`?^XR#PH`%QU0<@`+`HIW0`(<`@```6
MF>NO\/@!!,#T___W$94O$`"G=/_/D@`0`.,0'___<>P:_[)@9*?T_\62`"``
MI_3_SJ<I``"G]/_/P.7___7X!P<'!P<'ZZ_P4``DX_#_4/]QLD\`H.NJ`"``
M#;)/`*%!L/"DT@?PJ*`HN00`.\`@```6;\#E___Z4>PH`"X`?.-`\*0`%,0H
M``!(=.L4``,`#>,0(```".-0$`@`!.-0$```).Q8_^,`?.,`$!``!.,`$`@`
M)$$0$`CL!O_X`'RY!``[P"```!9$P.7___HF[";_V`!\N00`.\`@```6/L#E
M___Z&^PH`"X`?.,0\*0`%,18``!(/NOA``,`#>/@4```".,`X`@`!.,`X```
M).P(_^,`?.,PX!``!.,PX`@`)$'@X`CL-O_X`'RY!``[P"```!83P.7___GP
M[";_V`!\N00`.\`@```6#,#E___YY>PH`"X`?.-0\*0`%,3H``!(".M%``,`
M#>-`X```".,P0`@`!.,P0```).PX_^,`?.,@0!``!.,@0`@`)$%`0`CL)O_X
M`'RY!``[P"```!7AP.7___FZ[";_V`!\N00`.\`@```5V\#E___YK^PH`"X`
M?.,P\*0`%,0H``!'TNL3``,`#>,0(```".-`$`@`!.-`$```).Q(_^,`?.,`
M$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"```!6PP.7___F$[";_V`!\N00`
M.\`@```5J<#E___Y>>PH`"X`?.,0\*0`%,1(``!'G.M1``,`#>-00```".,`
M4`@`!.,`4```).P(_^,`?./@4!``!./@4`@`)$%04`CLYO_X`'RY!``[P"``
M`!5^P.7___E.[";_V`!\N00`.\`@```5>\#E___Y0^PH`"X`?.-`\*0`%,18
M``!'9NLT``,`#>,P4```"./@,`@`!./@,```).SH_^,`?.,@,!``!.,@,`@`
M)$$P,`CL)O_X`'RY!``[P"```!50P.7___D8[";_V`!\N00`.\`@```5'<#E
M___Y#>PH`"X`?./@\*0`%,0H``!',.L>``,`#>,0(```".,P$`@`!.,P$```
M).PX_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"```!3RP.7___CB
M[";_V`!\N00`.\`@```5%<#E___XU^PH`"X`?.,0\*0`%,0X``!&^NM!``,`
M#>-`,```".,`0`@`!.,`0```).P(_^,`?.-00!``!.-00`@`)$%`0`CL5O_X
M`'RY!``[P"```!3JP.7___BL[";_V`!\N00`.\`@```4Y,#E___XH>PH`"X`
M?.,P\*0`%,1(``!&Q.OC``,`#>/@0```".-0X`@`!.-0X```).Q8_^,`?.,@
MX!``!.,@X`@`)$'@X`CL)O_X`'RY!``[P"```!2YP.7___AV[";_V`!\N00`
M.\`@```4L\#E___X:^PH`"X`?.-0\*0`%,3H``!&CNL5``,`#>,0X```".,@
M$`@`!.,@$```).PH_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"``
M`!2(P.7___A`[";_V`!\N00`.\`@```42L#E___X->PH`"X`?.,0\*0`%,0H
M``!&6.LQ``,`#>,P(```".,`,`@`!.,`,```).P(_^,`?.-`,!``!.-`,`@`
M)$$P,`CL1O_X`'RY!``[P"```!0?P.7___@*[";_V`!\N00`.\`@```43,#E
M___W_[D$`#+L*``)`'S`(```%#?`Y?__^52Y!``[P"```!1"P.7___?LN00`
M,NPH``D`?,`@```40,#E___Y0;D$`#O`(```%#[`Y?__]]FY!``R["@`&@!\
MP"```!/>P.7___DNU0?PJ*`HIW0`(\`P```4.<`@```3\.NO\0``!,#T___Y
M';D$`#O`(```%"+`Y?__][6Y!``R["C_Y0!\P"```!/HP.7___D*I_3_W,#E
M___S+P<'!P?KO_!8`"3`(```$]CC\/]0_W&R3P"P03#PI.N[`"``#;)/`+'2
M!_"HL"C`Y?__]XOL*``A`'Q#$"``&"'`)P```#"YA``"N0,`,*<1`/_K4P`_
M``RG2```N?*`5-4'\*BP*+D4`"6G=``*Z[_Q"``$!_ZG6```I_3_\\#E___R
M[6``\(!@(/"(8$#PD&!@\)CK/_`8`"3$&```1:'C\/\X_W&Y!``R00#Q:+)/
M`"!!4/#(ZT(`(``-LD\`0>,@$```!-('\,!`*.,`\+``).-0\+@`).5(\*``
M`>5(\*@``$%`\*#`Y?__]0BG*0#_P.7___13!P<'!^N/\$``)./@\`#P<>/P
M\`#_<>,`__@`(+DA`/ZG)/_XN00`_N/P_U#_<>,`\*@`(.,0\*@0<:<Y``"Y
M!`""LD\`H*=)``+KJ@`@``VR3P"A0;#PH-('$`"@*,#E___R<<`Q__\``.R2
M__\`V>P),(``5;D$`""G"___N8$``Z<+``&Y`@"9N>*@`KD)`)#LE`"*`'RY
M!``YN00`**=)``#`Y?__\D[L*`"8_WRY!``[N00`*,!!``$`",#E___RX>PH
M`(7_?KD4`$+L3`!C!WWC%+_X_W'L&P!=0&7L43Z_`%7$Z```10_CX!```""G
MA`!HXQ`?__]Q[!L`3$!E[%@`)`!\[%@`%@%\[%@`"P)\X^`0```@IX0`5.,0
M'___<>/@$```(*>$`$SC$!___W'CX!```""GA`!$XQ`?__]Q[!L`*$!EX^`0
M```@IX0`.>,@'___<;D$`!+CX"```""GA``OXQ`O__]QX^`0```@IX0`)^,0
M+_[_<>/@+_[_(*>$`!_C$"_]_W'L&__>H&7"E``!``#``?__``#LD/]\8&2G
M*?__XX#PJ!!QU0>``*`HIW0`&.N/\/`0!`?^N>FP(;D(`"FG]/_PP"```!*Z
MP.7___[<P"```!*MP.7___[6P.7___&]Z^_P<``DX_#_8/]QP.7___%$P.7_
M__+1["@`!@!\XR`@```$Z^_Q$``$!_X'!P<'ZV_P,``DX_#_4/]QLD\`H+D$
M`++KJ@`@``U!,/"DLD\`H<`@```2B-('\*B@*,#E___V`>PH``D`?+D$`&*5
M`"``IW0`$M4'\*B@**=T`#>Y!``[P"```!)OZV_PX``$P/3___=(IP@``+D$
M`!NY!``VITD``+)>`$.G%/_^N0D`1J<I``"R7@`AIQ3__KD)`"M!(D`"P.7_
M__$'N00`2\!0```1X;D$`++`,```$E?`Y?__\HJG]/_(P.7___%%ZV_P,``D
MX_#^(/]QLD\`<.MW`"``#;)/`''`$```1`?2!_'8<"C2#_"X$!#2!_#($"#2
M+_#H$"C2#_#0$%C2!_#@$&A!D/"TN00`TKD$`#G`(```$9W`Y?__]8WL*``)
M`'RY!`"RE0`@`*=T`DC`Y?__\)O`Y?__\BCL*`$,`'SC@"````*GA`$&IP@`
M`*<I``"Y!``XLEX`(Z<4__ZY"0`HZR(``0`-IRL``<#E___PG.-`@```E+D$
M`+*Y!`!BE0"``*>$`!>Y!``KN18`1,`P```1W<#E___R%T&`@`%!L+`"XT"`
M``"4E0"``*=T_^U!H/#PP"```!&9I_0`":>K``CC(*_X_P*GA``@N00`.<#E
M___U+[D$`(+L*/_R`'R5`"``IX3_[<#E___UB^PH_^@`?KD$`"C`Y?__\:6Y
M!`"R["8`'0!\0:#PN..PH````J>$`!65`+``IX0`E[D$`"O`Y?__]6[L)@""
M`'ZGJP`(X["@```"IW3_[Z<(``"Y!`!6N00`*Z<Y``"G20``LEX`,J<4__ZR
M7@!%IQ3__KD)`#NY"0!&&C2G.@0$N10`H[D$`"K`Y?__\!;C8/"@`"2Y!`""
MP#```!%GN00`2\!@```17\!0```0YL#E___QD[D$`"BG.0'`P.7___)L["8`
M"_]^P.7___'66``@`.P&`6<1?KD$`"A!,/$8P.7___"Z&++L)@`-`'Y88/$P
MI^A``,!K``#P`.QN`'J`=KD$`%CC0-````3$B```0N;`,```$4WC((````3`
MY?__\%NGJ0``U0?QV'`HIW0!YKD$`"KK;_(0``0'_KD$`"NGJP`(P.7___$'
MN00`LNPH_V<`?*?T_WRGN0``I_3_>$&@\-#C(*````*GA``5N00`.<#E___T
M9NPH``<`?)4`(`"G=``9IZL`".,@H````J=T_^^G*0`-P(```!#<P.7__^^*
MIT@`4[D$`+*Y!`!BI_3^\\#E___PSZ>K``BY!`""["C_T0!\N00`$J<(``"G
MZ0``LEX`X:<4__ZY"0#BZRX``0`-IRL``:?T_LA88/$TP.7__^]`[&+_A&!V
M6!#Q,*<X`<#`&P```?_L$_]Z8':Y!``JP.7__^].N00`.;D$`*+`(```$.W`
MY?__]`JY!``R["@`V@!\XR#0```$P.7___>/N00`8NPH`,\`?*<(``"G20``
MN00`)K)>`$*G%/_^N0D`1NQ,`!X#?KD4`%3`X```$,GC%6_\_W&R70#AIQ3_
M_J=T``_L2`$5!'ZG2O_[N10`-$%#8`"5+T``IX0!"KD$`#G`(```$`;`Y?__
M\\CL*`"?`'SCD"```)3LF`"9`'[LF`"6,'[`,```$"S`(```#_'`Y?__]1/`
MY?__[GK`````$/BY!`!BN00`2+D$`"KC`/"@`"3`4```#[O`,```$)7`Y?__
M\&6G]``JP.7___"P6$`@`*=.`!&G=``KP.7__^Y7P%```!#5I[H``;D4`!NY
M!`!BXU#PJ``DN00`2+D$`"K`4```#Y3C$/"@`"3`,```$'+`Y?__\#NY!``J
MISD!P,#E___Q%.PH_]'_?KD$`"C`Y?__\4RY!``ZP"````]JP.7___2ZN00`
M*L#E___]/:?T_L:Y!`!8N10`8.-`T```!,0H``!!E<`P```/WN,@(```!,#E
M___O"J?T_J_`Y?___2/5!_'8<"BG=`"2N00`*^MO\A``!,#T___ON.-@T```
M!*?T_S&Y!``FISD``,#E___P?+D$`-+L*/]D`'[`Y?__^_:Y!`!B["3_7`!\
MITD``.,P;_;_<;D$`"W`Y?__[H6Y!``M03#QJ:=)``;`Y?__[QSL)@!?!GS`
M,```+QW5!3``\:FG=/\]XS!OSO]QITD``+D$`"W`Y?__[F=!8/&ON00`+;D$
M`#:G20`HP.7__^[\["8`/RA\P.```!`GN00`2+D$`"J2`/'7X^#PH``DP%``
M``[JP#````^\P.7__^^4I_3_8^/0T`@``J>$_O6G"```IRD``+D$`%VR7@`E
MIQ3__KD)`"WL+/[G`WWCXM_\_W'`$```#Y2R70`>IQ3__KGB@&VG]/[8P.7_
M_^XMP"````^)P.7___L]!P<'!^M_\#@`)./P_U#_<<"@``!`XK)/`+#C$*``
M``3KNP`@``VR3P"QXY&P```$08#PI-('\*BP*-(`D+&0L+D$`#C`(```#J7`
MY?__\G7L*``'`'R5,2``IX0`S<#E___X`^,@H```!..2L```!+D$`"FG60`#
MITD``<`P```/8\#E___O,[D$`)+L*``?`'SC,"`0``3C<*````3C,#````3`
M0```#U#C)[````3`Y?__[?SC0)`0``3C,$````210#`-IW0`O.-PH```!*=9
M``/C)[````2G20`!P#````\VP.7__^\"N00`DNPH`!P`?+D$`#C`(```#C#`
MY?__\ANY!`!"["@`?`!\XQ"0$``$XR>P```$XS`0```$P.7__^W$XZ"@```$
MITD``>.:L```!,`P```/"[D$`"G`Y?__[G3`0```#PZY!``RN00`*<#E___M
MJKD$`#C`(```#?CCBK````22`("QP.7___'CQ"L``$"<["@`*P!\ISD!P,#E
M___O@NPR``$`V.P\`!<!?^PH`!01?KD$`%+$N```0(+$2```0(/C,+````3`
M(```#NS`Y?__[%C5!_"HL"BG=`!0ZW_PZ``$!_[$*```0&K`Y?__^_?$*P``
M0&CL)O_/`'S`(```#L#`Y?__[#V5`"`!IX3_/*?T_S'`Y?__])+C![````3C
M4)`0``2Y!`!RXS!0```$N00`(.QX`!<`?+D$`$?`Y?__[3^Y!``GP.7__^]J
MI_3_=N,GL```!,#E___L8J?T_T#$Z```0"OC0.````3`Y?__[2>G]/]CP.7_
M_^SR!P?KG_!(`"3C\/]0_W&R3P"@N00`LNNJ`"``#4$P\*2R3P"AP"````V.
MT@?PJ*`HP.7___%-["@`$P!\XQ`@``"4[!@`#0!^[!@`"C!^[+@`!P!\E0"P
M`*=T``O5!_"HH"BG=``UZY_P^``$!_ZY!``KP.7___80ISD`+[D$`)+`Y?__
M[,^Y`@`B00`@`;D$`"FYXG`@P.7__^VDITD`!,`P```-I<#E___M/.PF_]@`
M?M4'\*B@**=T``JY!``KZY_P^``$P/3___&RP.7__^R)ZV_P,``DX_#\T/]Q
MLD\`L.N[`"``#;)/`+%!$/"HT@?S*+`HIPD`!$%0(#CC0%````3C,%`(``3K
MI``@``SCH!```"3K8P`@``SC8!`0`"3`2@````#C0!`(`"3`.@````#C,!`8
M`"1!4%`0IQL`(*<'_][C,/$0``3C@/$8``3CH/$@``3CD/"H``3C</"P``1!
M0/"XIPD`0+D$`-KCX$````2Y!``>XQ!`,`""N8(`$[F"`!GLH2"_(57LH2`^
M`5;CH$!P`"2Y!``XN00`E[D$`(VG2P`(IP<*VN-@(`@`!.-@\*``).-`(!``
M!.,`(!@`!.-0\+``!+GG`)3"6EJ">9FY@`"6N0@`4+F"`)#CX"````3K=@`"
M``SLKB"_)57L=@`A'E;LKB`Z!5;L-R"_`%7C$/"H``2YYS#4PAI:@GF9N8``
MWN,0("``"+F"`-2Y"``:N>A0C;D(`!GLD2"_`%7L43N_)57L60`Z!5:Y"`!8
MZZX``@`,[-4[OR55[*X`(1Y6XQ#PN``$[(H@OP!5N>>@9\(:6H)YF>QU(+\`
M5;F``&GLUP`Z!5:Y@@!CN0@`%.-0\,``!+D(`!;"6EJ">9FY"``=N0@`4^LY
M``(`#.PY`"$>5KF"`*/LD2"_`%7L83N_)56YY'`:N00`INRI`#H%5NQC(+\`
M5;F"`!CCT/#(``2Y"``5PMI:@GF9N0@`&KGH@%WKIP`"``SL@3N_)57LIP`A
M'E;L<2"_`%7LAP`Z!5:Y@@`ZXQ#PT``$N8``.<(:6H)YF;F"`#:Y"``UN>A@
M4;D(`#CL:B"_`%7KB0`"``SLB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$
M`*WLJ0`Z!5:Y@@`VXQ#PV``$N0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@
MOP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0
M\.``!+D(`#7"&EJ">9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CL
MDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%5KF"`#;C$/#H``2Y"``UPAI:@GF9
MN0@`.KGH8%'KIP`"``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20
M.+D$`(WLAP`Z!5:Y@@`VXQ#P\``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,
M[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`
M-N,0\/@`!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"
M`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C$/$```2Y"``UPAI:
M@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55
MN>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#Q"``$N0@`-<(:6H)YF;D(`#JYZ&!1ZZ<`
M`@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`.@56
MN8(`-N,0\1``!+D(`#7"&EJ">9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)`"$>
M5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%5KF"`#;C$/$8``2Y"``U
MPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5[-,[
MOR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q(``$N0@`-<(:6H)YF;D(`#BYZ&!1
MZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`
M.@56N8(`-N,0\2@`!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG
M`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C$/$P``2Y
M"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5
M[-,[OR55XQ#Q.``$N>1P.L(:6H)YF;F"`#:Y!`"MN0@`->RI`#H%5KGH8%&Y
M"``Z[&@@OP!5[-,[OR55ZZ<``@`,[-,@.@56[*<`(1Y6P#H`````N>>@>..`
M\4``!+F``'G"BEJ">9FY@@!VN>A@&+D(`'7K60`"``RY"`!][%D`(1Y6[)<[
MOR55[)<@.@56[&H@OP!5N>=0VNN#``(`#+F``-.Y@@#6N0@`T;D(`-FY!`"8
M[),`(1Y6[#T[OR55N>>0%>P](#H%5KF"`!?CH/%(``3C@/%0``3"JF[9ZZ'"
MBF[9ZZ&Y"`"FN1H`A;D:`*'L9R*_/E6Y"`"C[&<"(1Y6[#H[OR55N>=@&>PZ
M(#H%5KF"`!WL?2*_/E6Y&@"!['T"(1Y6N0@`@^,P\5@`!,(Z;MGKH;GG<%:Y
M&@`YN>>@E>P8.[\E5;D:`#GL&"`Z!5;CD/%@``2Y"``QPIINV>NA[-,[OR55
MN1H`ENS3(#H%5NQJ(K\^5>QJ`B$>5N.@\6@`!+GG8%?"JF[9ZZ&Y@@!8N1H`
MI[D:`)7L>"*_/E6Y"`"=['@"(1Y6[(D[OR55[(D@.@56N>=PUK/!`&CC@/%P
M``3"BF[9ZZ&Y&@"&L\T`9KF"`-.Y&@"MN0@`INQ:.[\E5>Q:(#H%5NQC(K\^
M5>,0\7@`!.QC`B$>5L(:;MGKH;GG8#>Y&@`7N8(`.>QY(K\^5;D:`(/L>0(A
M'E:Y"`"%N>=P5NR8.[\E5;F"`%KLF"`Z!5:Y&@`5XS#Q@``$N0@`&<(Z;MGK
MH>R:(K\^5;D:`#;LF@(A'E;LT3N_)56YYY!7[-$@.@56N8(`6..@\8@`!+D:
M`#7"JF[9ZZ&Y"``]N1H`I^QX(K\^5>QX`B$>5NR#.[\E5>R#(#H%5KGG<-FS
MP0!XXX#QD``$PHINV>NAN1H`B;/-`)>Y@@#1N1H`K;D(`*GL6CN_)57L6B`Z
M!5;L82*_/E7L80(A'E;C$/&8``2YYV#7PAINV>NAN8(`T[D:`!>Y&@"-[',B
MOSY5N0@`A>QS`B$>5NPX.[\E5;GG<%;L."`Z!5:Y@@!:XY#QH``$N1H`%<*:
M;MGKH;D(`!.Y&@"6[#HBOSY5[-$[OR55[#H"(1Y6[-$@.@56N><P5^.@\:@`
M!+F"`%C"JF[9ZZ&Y&@"5N1H`I[D(`)WL>"*_/E7L>`(A'E;LB3N_)57LB2`Z
M!5:YYW#3L\$`:..`\;``!,**;MGKH;D:`(.SS0`VN8(`T;D:`*VY"`"C[%H[
MOR55[%H@.@56[&$BOSY5[&$"(1Y6XQ#QN``$N>=@U\(:;MGKH;F"`-FY&@`7
MN1H`C>QY(K\^5;D(`(7L>0(A'E;LF#N_)56YYW!6[)@@.@56N8(`6N,P\<``
M!+D:`!7".F[9ZZ&Y"``9N1H`-NR:(K\^5>S1.[\E5>R:`B$>5NS1(#H%5KGG
MD%?CH/'(``2Y@@!8PJINV>NAN1H`-;D:`*>Y"``]['@BOSY5['@"(1Y6[(,[
MOR55[(,@.@56N>=PV;/!`'CC@/'0``3"BF[9ZZ&Y&@")L\T`E[F"`-'L82*_
M/E6Y&@"M[&$"(1Y6N>=@U[F"`-.Y"`"IN1H`C>Q:.[\E5>S3(K\^5>Q:(#H%
M5NS3`B$>5KGGT):Y@@":N0@`A>,0\=@`!.PX(+\`5>Q8.[\E5<(:;MGKH>Q3
M`#H%5KD:`!>Y&@`9[)HBOSY5N0@`%>R:`B$>5N.@\>``!+GGD'W"JF[9ZZ&Y
M@@"'N1H`INQA(+\`5>P1.[\E5>P6`#H%5KD:`*CC@/'H``2Y"`"APHJ/&[S<
MZQ,``@`,N1H`C>P3`"$>5NS1(+\`5;GDT%FSP0`H[#H[OR55[(H@OP!5N>80
MJ;F``*:Y@0"EL\T`4N-P\?``!,)ZCQN\W.PX`#H%5KD(`*6Y!`!7XW#Q^``$
MN1H`6<)ZCQN\W.N6``(`#.R6`"$>5KGDT&FY@0`9N>C0U[F``!BY@0`6N0@`
M%;D(`*.SP0!M[#H@OP!5[*H[OR55[*,`.@56N0@`H>L8``(`#.P8`"$>5NS1
M(+\`5;GDT%GL:B"_`%7LBCN_)56YYA"IN8``H[F!`*6SS0!6[(8`.@56XW#R
M```$N0@`I;D(`*C">H\;O-SK@P`"``RY!`!7[(,`(1Y6N1H`6>PZ.[\E5>R:
M(+\`5;F!`!BYY-"HN8``%KF!`!JY"``5[#D`.@56XW#R"``$N0@`,<)ZCQN\
MW.L6``(`#+GHT-?L%@`A'E;L82"_`%6YY&!8L\$`/;GF$-BY@`#9N8$`U;/-
M`%/L<R"_`%7L,SN_)57L-P`Z!5:Y"`#5N0@`T^LY``(`#.PY`"$>5KGD8).Y
M@0`3XZ#R$``$N8``%\*JCQN\W+F!`!FY!`!:N1H`6.R-(+\`5;D(`!7LW3N_
M)57LV``Z!5:Y"`#1[)T@OP!5ZQ<``@`,[!<`(1Y6XW#R&``$PGJ/&[S<N>A@
M9^QQ(+\`5;GD<%.YYA"CL\$`=KF``*BY@0"EL\T`5^S=.[\E5>-@\B``!+D(
M`*7LV0`Z!5;":H\;O-RY"`#:N00`5NRM(+\`5;D:`%/LW3N_)57K.``"``SL
MV@`Z!5;L.``A'E:YYC"!N>1P$[F``(FY@0"!ZQD``@`,N0@`A>P9`"$>5KD(
M`(WLT2"_`%6YY-!3N>80D^-@\B@`!+F``)K":H\;O-RY@0"5N0@`9[/!`":S
MS0!2['@@OP!5XV#R,``$N0@`E<)JCQN\W.R(.[\E5;D$`%;LAP`Z!5:Y&@!3
MN>B`.>N:``(`#.R:`"$>5KGDT*FY@0`9N8``%[F!`!JY"``5[(,@OP!5[&,[
MOR55XS#R.``$[&@`.@56PCJ/&[S<N0@`8>L7``(`#.P7`"$>5NQQ(+\`5;GD
M<%FYZ-#3N>80.;/!`&VY@``XN8$`-;/-`%;CT/)```3"VH\;O-SLIB"_`%6Y
M"``U[&8[OR55N00`7>QJ`#H%5KD:`%GCT/)(``3KF``"``S"VH\;O-SLF``A
M'E:YY'")N8$`&;GH<'VY@``:N8$`&+D(`!6Y"``VL\$`-^QC(+\`5>PS.[\E
M5>PV`#H%5KGH,%'K&@`"``SL&@`A'E;LT2"_`%6YY-!YN>80J;F``*:Y@0"G
ML\T`<^PU(+\`5>R%.[\E5;D(`*?L@P`Z!5:Y"`"HXU#R4``$['H@OP!5[(H[
MOR55PEJ/&[S<XZ#R6``$N1H`6<*JCQN\W.N6``(`#.R6`"$>5KGDT&FY@0`9
MN>C0VKF``!.Y@0`6N0@`%>R'`#H%5K/!`'VY"`"!ZQ,``@`,[!,`(1Y6[-$@
MOP!5N>306;GF$*FY@`"GN8$`I;/-`%?L:""_`%7L.#N_)56Y"`"E[#8`.@56
MXX#R8``$PHJ/&[S<N00`6+D:`%GKEP`"``SLEP`A'E:YY-!YN8$`&;F``!:Y
M@0`7N0@`%;D(`*/C@/)H``3L.B"_`%7"BH\;O-SLJCN_)57LHP`Z!5:Y"`"A
MZQ8``@`,[!8`(1Y6[&$@OP!5N>1@6>QZ(+\`5;GHT-CLBCN_)56SP0`MN>80
MJ;F``*.Y@0"EL\T`4NR'`#H%5N/0\G``!+D(`*7"VH\;O-RY"`"HN00`7;D:
M`%GLVB"_`%7KDP`"``SLDP`A'E;L.CN_)56YY&")N8$`&>P]`#H%5KF``!?C
MH/)X``2Y@0`8PJJ/&[S<N0@`%;GH8%JY"``Q[&,[OR55[&,@.@56ZQ<``@`,
ML\$`9NP7`"$>5N-@\H``!.R!(+\`5;GF$'FYY("IPFJ/&[S<N1H`:;/-`):Y
M@`!]N8$`>KD(`'6YZ)"7[%D[OR55[%D@.@56L\$`%NM]``(`#.Q]`"$>5KD$
M`-6SS0!1N>2`I^-@\H@`!,)JRF+!UKGH@(;`.@````"Y@0`7L\$`.+F``!/K
M@P`"``RY@0`:[(,`(1Y6N0@`%;/-`&.Y"``=XZ#RD``$N>>`U\*JRF+!UKF"
M`-FY&@"G['DBOSY5['D"(1Y6XY#RF``$PIK*8L'6N1H`F+/!`%JSP0`)L\T`
ME;D:`&WL,3N_)57L,2`Z!5:Y"``V[%,[OR55[%,@.@56N>=PJ+F"`*&Y&@":
MN0@`E;/-`%#L82*_/E7L80(A'E:YYV#7N8(`T^P9.[\E5;D:`%WL&2`Z!5:Y
M"``5[*$[OR55[*$@.@56L\$`*K/-`-+C@/*@``3CH/*H``3"BLIBP=;"JLIB
MP=:Y&@"'N1H`INQS(K\^5>QS`B$>5KGG<#;L:2*_/E6Y@@`Y[&D"(1Y6N1H`
M@[GG8%>Y"`"-N8(`4>R8.[\E5;D:`*7LF"`Z!5:Y"`"I[-H[OR55[-H@.@56
M[)$BOSY5XS#RL``$[)$"(1Y6PCK*8L'6N>>05KD:`#>Y@@!8N1H`-;D(`#WL
MTSN_)57LTR`Z!5;C$/*X``2SP0`=PAK*8L'6X]#RP``$N1H`%L+:RF+!UNQH
M(K\^5;D:`-GL:`(A'E:YYV")L\T`D;F"`(KL>B*_/E6Y&@`8['H"(1Y6N0@`
M&;GG<(;L43N_)56Y@@"#[%$@.@56XZ#RR``$PJK*8L'6N1H`IKD$`&WLTR*_
M/E6Y&@!HN0@`9>S3`B$>5KGGT#>Y@@`Q[%8[OR55N1H`H^Q6(#H%5KD(`*7L
M.CN_)57L.B`Z!5;C@/+0``3"BLIBP=:Y&@"'['$BOSY5['$"(1Y6XQ#RV``$
MN>=P7<(:RF+!UKF"`%:Y&@`=N1H`A>S6(K\^5;D(`(/LU@(A'E;L.#N_)56Y
MY]!G[#@@.@56N8(`:KD:`!:Y"``3[#HBOSY5[#H"(1Y6N><P;;F"`&CL43N_
M)57CD/+@``3L42`Z!5;"FLIBP=:Y&@"7N1H`ENQH(K\^5;D(`)7L:`(A'E;L
MB3N_)57LB2`Z!5:YYV!SL\$`2..`\O``!,**RF+!UKD:`(.SS0`TN8(`<>.@
M\N@`!,*JRF+!UKD:`*VY&@"G['$BOSY5N0@`H^QQ`B$>5NQ:.[\E5;GG<-;L
M6B`Z!5:Y@@#9XQ#R^``$N1H`C<(:RF+!UKD(`(6Y&@`6[&DBOSY5[&D"(1Y6
M[)@[OR55N>=@5^R8(#H%5KF"`%JY&@`5N0@`&>S1.[\E5>S1(#H%5NR:(K\^
M5>,P\P``!.R:`B$>5L(ZRF+!UKGGD%:Y&@`WN8(`6+D:`#6Y"``][-,[OR55
M[-,@.@56XZ#S"``$L\$`7<*JRF+!UN/0\Q``!+D:`*;"VLIBP=;L:"*_/E6Y
M&@#9[&@"(1Y6N>=@B;/-`)6Y@@"!N1H`J.R!(K\^5>R!`B$>5KGG@':Y@@!S
MN0@`J;D:`-?L6CN_)57L<R*_/E7L6B`Z!5;L<P(A'E:Y!``WXS`@(``(P#H`
M````XS`@(``DXQ#S&``$PAK*8L'6N1H`%KGH4&VYYW#8[)8@OP!5N>>@/>Q6
M.[\E5;D:`!/L60`Z!5:Y"``5[-HBOSY5ZUD``@`,[-H"(1Y6[%D`(1Y6N>?0
M-[D(`%2YZ`!]P%H`````XU`@$``DN>=@`\!Z`````.-P(!@`).QA(+\`5>.@
M\R``!,*JRF+!UKD(`.JY&@#H[($[OR55N1H`X.R&`#H%5N,0\*``!+D(`.BY
M"``6P.H`````X^`@```DP!H`````XQ`@"``DU0?S*+`HIW0`"NMO\V``!`?^
MN00`?J?T]07`Y?__X3P'!P<'!P?K[_!P`"2G*0"`X_#_8/]QP.7__^#>P#%G
M12,!P`_OS:N)XS`@```DXP`@"``DP$^8NMS^P%$0,E1VXT`@$``DXU`@&``D
MP#_#TN'PY4@@*```XS`@(``DY4@@,```Y4P@>```Z^_Q$``$!_X'!P<'ZV_P
M,``DZQ0``P`-XU`@*``$N00`<KD$`+2Y"``5XT`@,``$[`$@OP!5["0``0#9
MN3$`4;GB($+C\/]8_W'C`'`H`"3K:P`=``RYZ$"&XX!P,``DN00`T^,P<'@`
M$J=T`&1!8'`X[+P`.#]^[%O_P`#8[)T`0`#9ZX4`!@#>IXH``1)5IT@``;GR
M4(1!$'!XN00`K>,0\*``)+DA`&JGI``UXP#PH``$[`H`-R!EN00`V=(_8`"@
M`+D$`">GNO_`IZL`0,#E___T%KD4`+NGFP!`IX;_Y+DA`&VG1``@I\0`!KGH
ML"VY84!BN00`/;D$`":Y!`!+P.7__]_34+!P>.MO\-@`!`?^N00`V:?$_]/L
M:?_1H&6G]``!N>BP-KEA0-.G]/_DIZ@`0!NC&:M!8'`XN?(PJ[D$`":Y&``C
MN10`2NPM`"*@9;GH0.*YZ$"=N6%`WKD$`#T8VL#E___?H5K0<'A0T'!X[-;_
MS$!^N00`)QNZN00`V<#E___SO+D4`+NG]/]RN>A`G>PM_^7`9;EA0"FG]/_@
MZX_P0``DN00`L^.`,"@`!..0,#``!.P8.K\]5>/P_V#_<;D4`#%!0[`XDH!`
M`*<:``&Y!`"BN10`(4$RL#CL'`!).'ZG2`!`N?D0).Q!``J`=J<J__^Y%@`2
MQA````!+N00`*\#E___S>M<WL#BP.*<Y``#L.0`'8%7L.0@/8%7L.1`78%7L
M.1@?(%6Y!``K[(,`'P!5XX"P<``DP.7___->T@.@`+`$N00`*](#H`2P#-(#
MH`BP%-(#H`RP'-(#H!"P).N/\.``!,#T___B+:<(`#BY^1!0[`'_S(!VIUK_
M_[D6`.7&X`````BG]/_"UP`P`#``UP`P`#``!P<'!^OO\'``)+D$``^G^_]@
MXP#P```DZ^_Q$``$!_X`````)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4``!E>&4`+W!R;V,O)6DO)7,`
M+@!005)?5$5-4```4$%27U!23T=.04U%```Z`"\`4$523#5,24(``%!%4DQ,
M24(`4$523#5/4%0``%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?
M1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```Q`&QS965K(&9A:6QE9```<F5A
M9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```<&%R+0``
M)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP87(``'-H;W)T(')E
M860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-C,`
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"UE```M+0``55-%4@``55-%4DY!344``%1%35!$25(`5$U0
M`"]T;7```&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S
M:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K
M*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B
M4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@
M/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE
M+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L
M=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K
M("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@
M;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L
M("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL
M96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM
M;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E
M=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE
M;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D[
M"E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M
M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B
M72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO
M+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA
M9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG
M="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I
M8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B
M3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ
M<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F
M+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L
M("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D
M;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@
M=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@
M(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L
M;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5]
M.PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D
M92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[
M9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL
M96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG
M="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D
M9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'
M24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T
M(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D
M<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE0
M7TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A
M73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@
M7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@
M=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^
M.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T
M<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U
M=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP
M0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2![
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@
M,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE
M7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N
M86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD[
M"GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD
M9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@
M(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N
M9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF
M9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A
M8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI
M.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO
M<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S
M=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY
M("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C
M:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O
M9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*
M:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@
M,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E
M860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O
M+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@[
M"GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE
M*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?
M(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````<&5R;'AS:2YC
M``!#04-(10```````````1L#.P```-0````9__^#J```!4#__X>P````\/__
MB(````%`__^)$````7#__XIP```!J/__C/````'H__^-:````B3__XV@```"
M./__CL@```)\__^.T````I#__Y%````"T/__D7@```+\__^2X````T#__YAP
M```#=/__F/````.D__^9:````]#__YM0```$%/__FX````0T__^<0```!'#_
M_Z*````$P/__I.@```3\__^EN```!8#__[Q8```%P/__O,@```7D__^^8```
M!B``````````%``````!>E(``7@.`1L,#Z`!````````3````!S__X:X````
MS@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`HP*S\[-S,O*R<C'Q@Z@`4(+
M7`K/SLW,R\K)R,?&#J`!0@L````````L````;/__AS@```"0`$:*"HL)C`B-
M!XX&CP5&#M@#`GP*S\[-S,O*#J`!0@L````T````G/__AY@```%@`$:(#(D+
MB@J+"8P(C0>.!H\%1@[8`W8*S\[-S,O*R<@.H`%""P```````#P```#4__^(
MP````H``1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[8`@,!3@K/SLW,R\K)R,?&
M#J`!0@L````````X```!%/__BP````!T`$R&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.R`("8,_.S<S+RLG(Q\8.H`$````````0```!4/__BSP````X````````
M`$````%D__^+8````20`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z@(4P.H$%,
M#M!"`N0*S\[-S,O*R<C'Q@Z@`4(+````$````:C__XQ$````!@`````````\
M```!O/__C#@```)L`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.H"%,#N@C`GH*
MS\[-S,O*R<C'Q@Z@`4(+````*````?S__XYH````-@!*BPF,"(T'C@:/!4H.
MP`)<S\[-S,L.H`$```````!````"*/__CG0```%B`$:*"HL)C`B-!XX&CP5&
M#J`A3`[((@+T"L_.S<S+R@Z@`4(+7`K/SLW,R\H.H`%&"P```````#````)L
M__^/F```!8P`1HH*BPF,"(T'C@:/!48.T`(#!4H*S\[-S,O*#J`!1@L`````
M```L```"H/__E/0```"``$R+"8P(C0>.!H\%1@[0`@)>"L_.S<S+#J`!0@L`
M```````H```"T/__E40```!T`%R&#H<-B`R)"XH*BPF,"(T'C@:/!48.Z`(`
M`````$````+\__^5D````>@`1H@,B0N*"HL)C`B-!XX&CP5&#`Z@@018#0]&
M#M""!`,!D@K/SLW,R\K)R`Z@`4(+````````'````T#__Y<T````+`!&C@:/
M!48.P`)>S\X.H`$````X```#8/__ET0```#``$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!48.T`("5`K/SLW,R\K)R,?&#J`!1@L```!,```#G/__E\@```8\`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.@`4#`F`*S\[-S,O*R<C'Q@Z@`4(+`P*F
M"L_.S<S+RLG(Q\8.H`%&"P```#@```/L__^=N````F8`1H<-B`R)"XH*BPF,
M"(T'C@:/!48.T`(#`;X*S\[-S,O*R<C'#J`!0@L``````$````0H__^?Y```
M`-``1HD+B@J+"8P(C0>.!H\%1@[0`@)>"L_.S<S+RLD.H`%""P)8"L_.S<S+
MRLD.H`%&"P``````/```!&S__WY@```"@`!&A@Z'#8@,B0N*"HL)C`B-!XX&
MCP5&#N@"`P'`"L_.S<S+RLG(Q\8.H`%""P```````#P```2L__^@,```%IH`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,6?@K/SLW,R\K)R,?&#J`!0@L`
M```````@```$[/__MI````!L`$J.!H\%1@[``@):S\X.H`$````````X```%
M$/__MMP```&8`%*&#H<-B`R)"XH*BPF,"(T'C@:/!6P.R`("R`K/SLW,R\K)
MR,?&#J`!0@L````T```%3/__N#@```#\`$:(#(D+B@J+"8P(C0>.!H\%7`[`
M`@*H"L_.S<S+RLG(#J`!1@L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C$````````"*H``````````$````````"P@``
M```````!`````````LT`````````'0````````/_``````````P````````8
M*``````````-````````6P``````````&0```````+O(`````````!L`````
M````"``````````:````````N]``````````'``````````(`````&___O4`
M```````">``````````%````````#$``````````!@````````-8````````
M``H````````$'0`````````+`````````!@`````````%0``````````````
M``````,```````"]N``````````"````````!2@`````````%``````````'
M`````````!<````````3```````````'````````$&``````````"```````
M``*@``````````D`````````&``````````>``````````@`````;___^P``
M```(```!`````&____D`````````$```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````N]@`````````````````````````````&'(`
M```````8D@```````!BR````````&-(````````8\@```````!D2````````
M&3(````````94@```````!ER````````&9(````````9L@```````!G2````
M````&?(````````:$@```````!HR````````&E(````````:<@```````!J2
M````````&K(````````:T@```````!KR````````&Q(````````;,@``````
M`!M2````````&W(````````;D@```````!NR````````&](````````;\@``
M`````!P2````````'#(````````<4@```````!QR````````')(````````<
ML@```````!S2````````'/(````````=$@```````!TR````````'5(`````
M```=<@```````!V2````````';(````````=T@```````!WR````````'A(`
M```````>,@```````!Y2````````'G(````````>D@```````!ZR````````
M'M(````````>\@```````!\2````````'S(`````````````````````````
M```````````````8*```````````````````````````````````````````
M```````````````````?2```````````````````6P``````````````````
M``````````````````````#```I005(N<&T*``````````````````!>#```
M`````%MH``````````````````!<"````````%P,````````7@````````!;
M;@```````%X(``````````````````!=\````````%WV````````````````
M``!>$D=#0SH@*$%L<&EN92`Q-"XR+C`I(#$T+C(N,```+G-H<W1R=&%B`"YN
M;W1E+F=N=2YB=6EL9"UI9``N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M``````````````````````````````````L````'``````````(````````"
M.`````````(X`````````"0````````````````````$```````````````>
M`````0`````````"`````````EP````````"7``````````8````````````
M`````````0``````````````)F____8``````````@````````)X````````
M`G@`````````W`````0```````````````@``````````````#`````+````
M``````(````````#6`````````-8````````".@````%`````@`````````(
M`````````!@````X`````P`````````"````````#$`````````,0```````
M``0=`````````````````````0``````````````0`````0``````````@``
M`````!!@````````$&`````````"H`````0```````````````@`````````
M&````$H````$`````````$(````````3`````````!,`````````!2@````$
M````$@`````````(`````````!@```!4`````0`````````&````````&"@`
M```````8*``````````<`````````````````````@``````````````3P``
M``$`````````!@```````!A$````````&$0````````'````````````````
M``````0`````````(````%H````!``````````8````````?2````````!](
M````````.[@````````````````````(``````````````!@`````0``````
M```&````````6P````````!;```````````<`````````````````````@``
M````````````9@````$``````````@```````%L@````````6R````````!`
M@`````````````````````@``````````````&X````!``````````(`````
M``";H````````)N@`````````-0````````````````````$````````````
M``!\`````0`````````"````````G'@```````"<>`````````6$````````
M````````````"```````````````A@````X``````````P```````+O(````
M````J\@`````````"`````````````````````@`````````"````)(````/
M``````````,```````"[T````````*O0``````````@`````````````````
M```(``````````@```">````!@`````````#````````N]@```````"KV```
M``````'@````!0``````````````"``````````0````IP````$`````````
M`P```````+VX````````K;@````````"2`````````````````````@`````
M````"````*P````!``````````,```````#``````````+```````````(``
M```````````````````(``````````````"R````"``````````#````````
MP(````````"P@`````````!8````````````````````"```````````````
MMP````$`````````,```````````````````L(``````````'```````````
M``````````$``````````0````$````#````````````````````````````
C`+"<`````````,`````````````````````!````````````
